AffySTPDInfoPkgSeed-class: Class "AffySTPDInfoPkgSeed" for the Sense Target gene-level array
Description
container for parameters related to pdmapping package construction for ST type arraysObjects from the Class
Objects can be created by calls of the form new("AffySTPDInfoPkgSeed", pgfFile, clfFile, probeFile, transFile, ...).Slots
pgfFile:- Object of class
"ScalarCharacter" path to pgf clfFile:- Object of class
"ScalarCharacter" path to clf probeFile:- Object of class
"ScalarCharacter", path to probe sequence file (Optional) transFile:- Object of class
"ScalarCharacter", path to trans file (Optional) chipName:- Name of the chip or platform
manufacturer:- chip/platform manufacturer
url:- chip URL
genomebuild:- The genome build this platform is based
upon.
organism:- organism for chip.
species:- species for chip.
version:- A character vector giving the version
number of the package.
license:- The license of the package
author:- Author of the package
email:- An email address to use in the Maintainer field
biocViews:- Character data for the biocViews field of
the DESCRIPTION file
Methods
- chipName
signature(object = "AffySTPDInfoPkgSeed"): ... - getGeometry
signature(object = "AffySTPDInfoPkgSeed"): ... - makePdInfoPackage
signature(object = "AffySTPDInfoPkgSeed"): ...
Examples
Run this codeshowClass("AffySTPDInfoPkgSeed")
Run the code above in your browser using DataLab