Learn R Programming

pdInfoBuilder (version 1.36.0)

AffyTilingPDInfoPkgSeed-class: Class "AffyTilingPDInfoPkgSeed"

Description

PD Info Package Seed for Affymetrix Tiling Arrays

Arguments

Objects from the Class

Objects can be created by calls of the form new("AffyTilingPDInfoPkgSeed", ...).

Slots

bpmapFile:
BPMAP File - provided by Affymetrix
celFile:
CEL File - provided by Affymetrix
chipName:
Name of the chip or platform
manufacturer:
chip/platform manufacturer
url:
chip URL
genomebuild:
The genome build this platform is based upon.
organism:
organism for chip.
species:
species for chip.
version:
A character vector giving the version number of the package.
license:
The license of the package
author:
Author of the package
email:
An email address to use in the Maintainer field
biocViews:
Character data for the biocViews field of the DESCRIPTION file

Methods

makePdInfoPackage
signature(object = "AffyTilingPDInfoPkgSeed"): ...
chipName
signature(object = "AffyTilingPDInfoPkgSeed"): ...

Examples

Run this code
showClass("AffyTilingPDInfoPkgSeed")

Run the code above in your browser using DataLab