NgsExpressionPDInfoPkgSeed-class: Class "NgsExpressionPDInfoPkgSeed"
Description
PDInfo package Seed for NimbleGen Expression arraysObjects from the Class
Objects can be created by calls of the form new("NgsExpressionPDInfoPkgSeed", ndfFile, pairFile, xysFile, ngdFile ...).Slots
ndfFile:- NDF (NimbleGen Design) file
xysFile:- XYS File - used as template
chipName:- Name of the chip or platform
manufacturer:- chip/platform manufacturer
url:- chip URL
genomebuild:- The genome build this platform is based
upon.
organism:- organism for chip.
species:- species for chip.
version:- A character vector giving the version
number of the package.
license:- The license of the package
author:- Author of the package
email:- An email address to use in the Maintainer field
biocViews:- Character data for the biocViews field of
the DESCRIPTION file
Methods
- makePdInfoPackage
signature(.Object = "NgsExpressionPDInfoPkgSeed"): ... - chipName
signature(object = "NimbleGenPDInfoPkgSeed"): ... - getGeometry
signature(.Object = "NimbleGenPDInfoPkgSeed"): ...
Examples
Run this codeshowClass("NgsExpressionPDInfoPkgSeed")
Run the code above in your browser using DataLab